@@ -15,10 +15,12 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 import json
 import warnings
 from collections import OrderedDict
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Sequence
+from typing import TYPE_CHECKING, Any, Callable, List, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -66,9 +68,9 @@ class HiveStatsCollectionOperator(BaseOperator):
         *,
         table: str,
         partition: Any,
-        extra_exprs: Optional[Dict[str, Any]] = None,
-        excluded_columns: Optional[List[str]] = None,
-        assignment_func: Optional[Callable[[str, str], Optional[Dict[Any, Any]]]] = None,
+        extra_exprs: dict[str, Any] | None = None,
+        excluded_columns: list[str] | None = None,
+        assignment_func: Callable[[str, str], dict[Any, Any] | None] | None = None,
         metastore_conn_id: str = 'metastore_default',
         presto_conn_id: str = 'presto_default',
         mysql_conn_id: str = 'airflow_db',
@@ -95,12 +97,12 @@ class HiveStatsCollectionOperator(BaseOperator):
         self.ds = '{{ ds }}'
         self.dttm = '{{ execution_date.isoformat() }}'
 
-    def get_default_exprs(self, col: str, col_type: str) -> Dict[Any, Any]:
+    def get_default_exprs(self, col: str, col_type: str) -> dict[Any, Any]:
         """Get default expressions"""
         if col in self.excluded_columns:
             return {}
         exp = {(col, 'non_null'): f"COUNT({col})"}
-        if col_type in ['double', 'int', 'bigint', 'float']:
+        if col_type in {'double', 'int', 'bigint', 'float'}:
             exp[(col, 'sum')] = f'SUM({col})'
             exp[(col, 'min')] = f'MIN({col})'
             exp[(col, 'max')] = f'MAX({col})'
@@ -108,13 +110,13 @@ class HiveStatsCollectionOperator(BaseOperator):
         elif col_type == 'boolean':
             exp[(col, 'true')] = f'SUM(CASE WHEN {col} THEN 1 ELSE 0 END)'
             exp[(col, 'false')] = f'SUM(CASE WHEN NOT {col} THEN 1 ELSE 0 END)'
-        elif col_type in ['string']:
+        elif col_type == 'string':
             exp[(col, 'len')] = f'SUM(CAST(LENGTH({col}) AS BIGINT))'
             exp[(col, 'approx_distinct')] = f'APPROX_DISTINCT({col})'
 
         return exp
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         metastore = HiveMetastoreHook(metastore_conn_id=self.metastore_conn_id)
         table = metastore.get_table(table_name=self.table)
         field_types = {col.name: col.type for col in table.sd.cols}
@@ -130,7 +132,7 @@ class HiveStatsCollectionOperator(BaseOperator):
             exprs.update(assign_exprs)
         exprs.update(self.extra_exprs)
         exprs = OrderedDict(exprs)
-        exprs_str = ",\n        ".join(v + " AS " + k[0] + '__' + k[1] for k, v in exprs.items())
+        exprs_str = ",\n        ".join(f"{v} AS {k[0]}__{k[1]}" for k, v in exprs.items())
 
         where_clause_ = [f"{k} = '{v}'" for k, v in self.partition.items()]
         where_clause = " AND\n        ".join(where_clause_)
@@ -138,7 +140,7 @@ class HiveStatsCollectionOperator(BaseOperator):
 
         presto = PrestoHook(presto_conn_id=self.presto_conn_id)
         self.log.info('Executing SQL check: %s', sql)
-        row = presto.get_first(hql=sql)
+        row = presto.get_first(sql)
         self.log.info("Record: %s", row)
         if not row:
             raise AirflowException("The query returned None")
