@@ -15,12 +15,12 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """This module contains an operator to move data from MSSQL to Hive."""
+from __future__ import annotations
 
 from collections import OrderedDict
 from tempfile import NamedTemporaryFile
-from typing import TYPE_CHECKING, Dict, Optional, Sequence
+from typing import TYPE_CHECKING, Sequence
 
 import pymssql
 import unicodecsv as csv
@@ -77,11 +77,11 @@ class MsSqlToHiveOperator(BaseOperator):
         hive_table: str,
         create: bool = True,
         recreate: bool = False,
-        partition: Optional[Dict] = None,
+        partition: dict | None = None,
         delimiter: str = chr(1),
         mssql_conn_id: str = 'mssql_default',
         hive_cli_conn_id: str = 'hive_cli_default',
-        tblproperties: Optional[Dict] = None,
+        tblproperties: dict | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -106,7 +106,7 @@ class MsSqlToHiveOperator(BaseOperator):
         }
         return map_dict.get(mssql_type, 'STRING')
 
-    def execute(self, context: "Context"):
+    def execute(self, context: Context):
         mssql = MsSqlHook(mssql_conn_id=self.mssql_conn_id)
         self.log.info("Dumping Microsoft SQL Server query results to local file")
         with mssql.get_conn() as conn:
@@ -115,9 +115,7 @@ class MsSqlToHiveOperator(BaseOperator):
                 with NamedTemporaryFile("w") as tmp_file:
                     csv_writer = csv.writer(tmp_file, delimiter=self.delimiter, encoding='utf-8')
                     field_dict = OrderedDict()
-                    col_count = 0
-                    for field in cursor.description:
-                        col_count += 1
+                    for col_count, field in enumerate(cursor.description, start=1):
                         col_position = f"Column{col_count}"
                         field_dict[col_position if field[0] == '' else field[0]] = self.type_map(field[1])
                     csv_writer.writerows(cursor)
